@@ -91,8 +91,8 @@ def main():
     api= config['DEFAULT']['ApiKey']
     #API connection for CC
     endpoint = config['DEFAULT']['EndPoint']
-    url = endpoint + '/v1/template-scanner/scan'
-    url2 = endpoint + '/v1/services'
+    url = endpoint + '/template-scanner/scan'
+    url2 = endpoint + '/services'
 
     headers = {
         'Content-Type': 'application/vnd.api+json',
